API documentation
=================


Broadening
-----------

.. automodule:: scope.broadening
    :members:
    :undoc-members:
    :show-inheritance:

Fitting
--------
.. automodule:: scope.emcee_fit_hires
    :members:
    :undoc-members:
    :show-inheritance:

Utility functions
-------------------

.. automodule:: scope.utils
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: scope.run_simulation
    :members:
    :undoc-members:
    :show-inheritance:


Tellurics
------------------

.. automodule:: scope.tellurics
    :members:
    :undoc-members:
    :show-inheritance:

Noise
------------------

.. automodule:: scope.noise
    :members:
    :undoc-members:
    :show-inheritance:

R-M effect
------------------

.. automodule:: scope.rm_effect
    :members:
    :undoc-members:
    :show-inheritance:

Cross-correlation
------------------

.. automodule:: scope.ccf
    :members:
    :undoc-members:
    :show-inheritance:


Running simulation
--------------------

.. automodule:: scope.run_simulation
    :members:
    :undoc-members:
    :show-inheritance:


Calculating quantities
-----------------------

.. automodule:: scope.calc_quantities
    :members:
    :undoc-members:
    :show-inheritance:


Input / output
-----------------------

.. automodule:: scope.input_output
    :members:
    :undoc-members:
    :show-inheritance:


MCMC fitting
-----------------------

.. automodule:: scope.emcee_fit_hires
    :members:
    :undoc-members:
    :show-inheritance:
